@@ -17,7 +17,9 @@ renviron_d <- function(sibling = FALSE, all = FALSE, unload = FALSE, skip = NA,
     # Load custom .Renviron.d/* files
     if (is.null(paths)) paths <- find_renviron_d(sibling = sibling, all = all)
     files <- list_d_files(paths, filter = filter_files)    
-    files_apply(files, fun = readRenviron, dryrun = dryrun, what = "Renviron")
+    files_apply(files, fun = readRenviron,
+                dryrun = dryrun, what = "Renviron",
+                debug = debug)
   }
 
   res <- api()
